#
# Configuration file for using the XML library in GNOME applications
#
XML2_LIBDIR="-L/opt/concourse/worker/volumes/live/427291d8-4994-4ba7-65e5-f2b1f6313dc6/volume/libxml2_1624477889094/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib"
XML2_LIBS="-lxml2 -L/opt/concourse/worker/volumes/live/427291d8-4994-4ba7-65e5-f2b1f6313dc6/volume/libxml2_1624477889094/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib -lz -L/opt/concourse/worker/volumes/live/427291d8-4994-4ba7-65e5-f2b1f6313dc6/volume/libxml2_1624477889094/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib -llzma -lpthread -L/opt/concourse/worker/volumes/live/427291d8-4994-4ba7-65e5-f2b1f6313dc6/volume/libxml2_1624477889094/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib -liconv -L/opt/concourse/worker/volumes/live/427291d8-4994-4ba7-65e5-f2b1f6313dc6/volume/libxml2_1624477889094/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib -licui18n -licuuc -licudata -lm "
XML2_INCLUDEDIR="-I/opt/concourse/worker/volumes/live/427291d8-4994-4ba7-65e5-f2b1f6313dc6/volume/libxml2_1624477889094/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/include/libxml2 -I/opt/concourse/worker/volumes/live/427291d8-4994-4ba7-65e5-f2b1f6313dc6/volume/libxml2_1624477889094/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/include"
MODULE_VERSION="xml2-2.9.12"

